diamondback.interfaces package — diamondback documentation

# diamondback.interfaces package

## Submodules

## diamondback.interfaces.IA module

Description

> Recursive coefficient interface.

Example

>     from diamondback import IA
>     import numpy

>     class Test( IA ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.a = numpy.array( [ 0.0, 0.1 ] )

>     test = Test( )

>     test.a[ : ] = 0.0

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-01-31.

Definition

class `diamondback.interfaces.IA.` `IA`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Recursive coefficient interface.

  Initialize.

  property `a`

    typing.Union[ typing.List, numpy.ndarray ] - recursive coefficient.

    Type

      a

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IB module

Description

> Forward coefficient interface.

Example

>     from diamondback import IB
>     import numpy

>     class Test( IB ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.b = numpy.array( [ 0.75, 0.25 ] )

>     test = Test( )

>     test.b[ : ] = 0.5

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-01-31.

Definition

class `diamondback.interfaces.IB.` `IB`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Forward coefficient interface.

  Initialize.

  property `b`

    typing.Union[ typing.List, numpy.ndarray ] - forward coefficient.

    Type

      b

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IClear module

Description

> Clear interface.

Example

>     from diamondback import IClear, IPhase

>     class Test( IClear, IPhase ) :

>         def clear( self ) -> None :

>             self.phase = 0.0

>     test = Test( )

>     test.clear( )

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2019-01-25.

Definition

class `diamondback.interfaces.IClear.` `IClear`

  Bases: `abc.ABC`

  Clear interface.

  Initialize.

  abstract `clear`() → None

    Clears an instance.

## diamondback.interfaces.IConfigure module

Description

> Configure interface.

Example

>     from diamondback import IConfigure

>     class Test( IConfigure ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.configure = [ ]

>     test = Test( )

>     test.configure = { 'a' : 0.0, 'b' : 1.0 }

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2020-10-27.

Definition

class `diamondback.interfaces.IConfigure.` `IConfigure`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Configure interface.

  Initialize.

  property `configure`

    typing.Any.

    Type

      configure

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.ICount module

Description

> Count interface.

Example

>     from diamondback import ICount

>     class Test( ICount ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.count = 0

>     test = Test( )

>     test.count = 3

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2021-01-08.

Definition

class `diamondback.interfaces.ICount.` `ICount`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Count interface.

  Initialize.

  property `count`

    int - in [ 0, inf ).

    Type

      count

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IData module

Description

> Data interface.

Example

>     from diamondback import IData

>     class Test( IData ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.data = [ ]

>     test = Test( )

>     test.data = { 'a' : 0.0, 'b' : 1.0 }

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-07-12.

Definition

class `diamondback.interfaces.IData.` `IData`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Data interface.

  Initialize.

  property `data`

    typing.Any.

    Type

      data

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IDate module

” Description

> Date interface.

Example

>     from diamondback import IDate
>     import datetime

>     class Test( IDate ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.date = datetime.datetime.utcnow( ).replace( microsecond = 0, tzinfo = datetime.timezone.utc )

>     test = Test( )

>     test.date += datetime.timedelta( hours = 4 )

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-07-12.

Definition

class `diamondback.interfaces.IDate.` `IDate`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Date interface.

  Initialize.

  property `date`

    datetime.datetime.

    Type

      date

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IDispose module

Description

> Dispose interface.

Example

>     from diamondback import IDispose

>     class Test( IDispose ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.dispose = False

>     test = Test( )

>     test.dispose = True

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2020-10-22.

Definition

class `diamondback.interfaces.IDispose.` `IDispose`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Dispose interface.

  Initialize.

  property `dispose`

    bool.

    Type

      dispose

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IDuration module

Description

> Duration interface.

Example

>     from diamondback import IDuration

>     class Test( IDuration ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.duration = 0.0

>     test = Test( )

>     test.duration = 3600.0

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-07-12.

Definition

class `diamondback.interfaces.IDuration.` `IDuration`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Duration interface.

  Initialize.

  property `duration`

    float - in seconds in [ 0.0, inf ).

    Type

      duration

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IEqual module

Description

> Equal interface.

Example

>     from diamondback import IEqual, IPhase
>     import typing

>     class Test( IEqual, IPhase ) :

>         def __eq__( self, other : typing.Any ) -> bool :

>             return ( ( super( ).__eq__( other ) ) and ( numpy.isclose( self.phase, other.phase ) ) )

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-01-23.

Definition

class `diamondback.interfaces.IEqual.` `IEqual`

  Bases: `object`

  Equal interface.

  Initialize.

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

  `__ne__`(other: Any) → bool

    Not equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > notequal : bool.

## diamondback.interfaces.IFrequency module

Description

> Frequency interface.

Example

>     from diamondback import IFrequency

>     class Test( IFrequency ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.frequency = 1.0

>     test = Test( )

>     test.frequency = 0.5

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-01-31.

Definition

class `diamondback.interfaces.IFrequency.` `IFrequency`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Frequency interface.

  Initialize.

  property `frequency`

    float - relative to Nyquist in [ -1.0, 1.0 ].

    Type

      frequency

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IIdentity module

Description

> Identity interface.

Example

>     from diamondback import IIdentity
>     import uuid

>     class Test( IIdentity ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.identity = str( uuid.uuid4( ) )

>     test = Test( )

>     test.identity

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2020-09-23.

Definition

class `diamondback.interfaces.IIdentity.` `IIdentity`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Identity interface.

  Initialize.

  property `identity`

    str.

    Type

      identity

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IInterval module

Description

> Interval interface.

Example

>     from diamondback import IInterval

>     class Test( IInterval ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.interval = 0.0

>     test = Test( )

>     test.interval = 7200.0

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-07-12.

Definition

class `diamondback.interfaces.IInterval.` `IInterval`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Interval interface.

  Initialize.

  property `interval`

    float - in seconds in [ 0.0, inf ).

    Type

      interval

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.ILabel module

Description

> Label interface.

Example

>     from diamondback import ILabel

>     class Test( ILabel ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.label = ''

>     test = Test( )

>     test.label = 'label'

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2021-03-15.

Definition

class `diamondback.interfaces.ILabel.` `ILabel`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Label interface.

  Initialize.

  property `label`

    str.

    Type

      label

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.ILatency module

Description

> Latency interface.

Example

>     from diamondback import ILatency

>     class Test( ILatency ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.latency = 0.0

>     test = Test( )

>     test.latency = 600.0

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-07-12.

Definition

class `diamondback.interfaces.ILatency.` `ILatency`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Latency interface.

  Initialize.

  property `latency`

    float - in seconds in [ 0.0, inf ).

    Type

      latency

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.ILive module

Description

> Live interface.

Example

>     from diamondback import ILive

>     class Test( ILive ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.live = False

>     test = Test( )

>     test.live = True

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2021-01-12.

Definition

class `diamondback.interfaces.ILive.` `ILive`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Live interface.

  Initialize.

  property `live`

    bool.

    Type

      live

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IModel module

Description

> Model interface.

Example

>     from diamondback import IModel, Serial

>     class Test( IModel ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.model = [ ]

>     test = Test( )

>     test.model = Serial.encode( { 'a' : 0.0, 'b' : 1.0 } )

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-07-12.

Definition

class `diamondback.interfaces.IModel.` `IModel`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Model interface.

  Initialize.

  property `model`

    typing.Any.

    Type

      model

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IPath module

Description

> Path interface.

Example

>     from diamondback import IPath

>     class Test( IPath ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.path = ''

>     test = Test( )

>     test.path = '.\data'

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2020-01-09.

Definition

class `diamondback.interfaces.IPath.` `IPath`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Path interface.

  Initialize.

  property `path`

    str.

    Type

      path

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IPeriod module

Description

> Period interface.

Example

>     from diamondback import IPeriod

>     class Test( IPeriod ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.period = 0.0

>     test = Test( )

>     test.period = 300.0

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-07-12.

Definition

class `diamondback.interfaces.IPeriod.` `IPeriod`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Period interface.

  Initialize.

  property `period`

    float - in seconds in [ 0.0, inf ).

    Type

      period

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IPhase module

Description

> Phase interface.

Example

>     from diamondback import IPhase

>     class Test( IPhase ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.phase = 0.0

>     test = Test( )

>     test.phase = 0.5

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-01-31.

Definition

class `diamondback.interfaces.IPhase.` `IPhase`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Phase interface.

  Initialize.

  property `phase`

    float - relative to pi in [ -1.0, 1.0 ].

    Type

      phase

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IProxy module

Description

> Proxy interface.

Example

>     from diamondback import IProxy

>     class Test( IProxy ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.proxy = { 'http' : 'http://proxy.net:9480', 'https' : 'https://proxy.net:8080' }

>     test = Test( )

>     test.proxy[ 'http' ] = 'http://proxy.net:80'

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2020-09-25.

Definition

class `diamondback.interfaces.IProxy.` `IProxy`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Proxy interface.

  Initialize.

  property `proxy`

    typing.Dict[ str, str ].

    Type

      proxy

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IQ module

Description

> State derivative interface.

Example

>     from diamondback import IQ
>     import numpy

>     class Test( IQ ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.q = numpy.array( [ 0.0, 0.1 ] )

>     test = Test( )

>     test.q[ : ] = 0.1

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-01-31.

Definition

class `diamondback.interfaces.IQ.` `IQ`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  State derivative interface.

  Initialize.

  property `q`

    typing.Union[ typing.List, numpy.ndarray ] - state derivative.

    Type

      q

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IRate module

Description

> Rate interface.

Example

>     from diamondback import IRate

>     class Test( IRate ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.rate = 5.0e-2

>     test = Test( )

>     test.rate = 1.0e-3

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-01-31.

Definition

class `diamondback.interfaces.IRate.` `IRate`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Rate interface.

  Initialize.

  property `rate`

    float - in [ 0.0, inf ).

    Type

      rate

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IReady module

Description

> Ready interface.

Example

>     from diamondback import IReady

>     class Test( IReady ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.ready = False

>     test = Test( )

>     test.ready = True

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2021-01-12.

Definition

class `diamondback.interfaces.IReady.` `IReady`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Ready interface.

  Initialize.

  property `ready`

    bool.

    Type

      ready

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IReset module

Description

> Reset interface.

Example

>     from diamondback import IReset, IS
>     import numpy
>     import typing

>     class Test( IReset, IS ) :

>         def reset( self, x : typing.Union[ complex, float ] ) -> None :

>             self.s[ : ] = x

>     test = Test( )

>     test.s = numpy.array( [ 0.0, 1.0 ] )

>     test.reset( 0.5 )

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-03-12.

Definition

class `diamondback.interfaces.IReset.` `IReset`

  Bases: `abc.ABC`

  Reset interface.

  Initialize.

  abstract `reset`(x: Union[complex, float]) → None

    Modifies a state to minimize edge effects by assuming persistent operation at a specified incident signal condition.

    Arguments :

    > x : typing.Union[ complex, float ] - incident signal.

## diamondback.interfaces.IResolution module

Description

> Resolution interface.

Example

>     from diamondback import IResolution

>     class Test( IResolution ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.resolution = 0.5

>     test = Test( )

>     test.resolution = 0.1

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-07-12.

Definition

class `diamondback.interfaces.IResolution.` `IResolution`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Resolution interface.

  Initialize.

  property `resolution`

    float - in ( 0.0, inf ).

    Type

      resolution

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IRotation module

Description

> Rotation interface.

Example

>     from diamondback import IRotation

>     class Test( IRotation ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.rotation = 0.0

>     test = Test( )

>     test.rotation = 90.0

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2019-10-09.

Definition

class `diamondback.interfaces.IRotation.` `IRotation`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Rotation interface.

  Initialize.

  property `rotation`

    float.

    Type

      rotation

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IS module

Description

> State interface.

Example

>     from diamondback import IS
>     import numpy

>     class Test( IS ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.s = numpy.array( [ 0.0, 0.1 ] )

>     test = Test( )

>     test.s[ : ] = 0.0

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-01-31.

Definition

class `diamondback.interfaces.IS.` `IS`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  State interface.

  Initialize.

  property `s`

    typing.Union[ typing.List, numpy.ndarray ] - state.

    Type

      s

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IStream module

Description

> Stream interface.

Example

>     from diamondback import IStream
>     import sys

>     class Test( IStream ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.stream = sys.stdout

>     test = Test( )

>     test.stream = sys.stderr

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2020-10-15.

Definition

class `diamondback.interfaces.IStream.` `IStream`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Stream interface.

  Initialize.

  property `stream`

    typing.Any.

    Type

      stream

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.ITimeOut module

Description

> Time out interface.

Example

>     from diamondback import ITimeOut

>     class Test( ITimeOut ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.timeout = ( 10.0, 60.0 )

>     test = Test( )

>     test.timeout = ( 15.0, 120.0 )

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2019-10-09.

Definition

class `diamondback.interfaces.ITimeOut.` `ITimeOut`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Time out interface.

  Initialize.

  property `timeout`

    typing.Any.

    Type

      timeout

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.ITimeZone module

” Description

> Time zone interface.

Example

>     from diamondback import ITimeZone
>     import datetime
>     import pytz

>     class Test( ITimeZone ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.timezone = datetime.timezone.utc

>     test = Test( )

>     test.timezone = pytz.timezone( 'US/Eastern' )

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2018-07-12.

Definition

class `diamondback.interfaces.ITimeZone.` `ITimeZone`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Time zone interface.

  Initialize.

  property `timezone`

    datetime.timezone.

    Type

      timezone

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IUrl module

Description

> Url interface.

Example

>     from diamondback import IUrl

>     class Test( IUrl ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.url = 'http://127.0.0.1:8080/service'

>     test = Test( )

>     test.url = 'http://10.0.0.1:8080/service'

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2020-09-25.

Definition

class `diamondback.interfaces.IUrl.` `IUrl`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Url interface.

  Initialize.

  property `url`

    str.

    Type

      url

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IValid module

Description

> Valid interface.

Example

>     from diamondback import IValid

>     class Test( IValid ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.valid = False

>     test = Test( )

>     test.valid = True

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2020-10-22.

Definition

class `diamondback.interfaces.IValid.` `IValid`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Valid interface.

  Initialize.

  property `valid`

    bool.

    Type

      valid

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## diamondback.interfaces.IVersion module

Description

> Version interface.

Example

>     from diamondback import IVersion

>     class Test( IVersion ) :

>         def __init__( self ) -> None :

>             super( ).__init__( )

>             self.version = '1.0.1'

>     test = Test( )

>     test.version = '1.0.2'

License

> BSD-3C.

> © 2018 - 2021 Larry Turner, Schneider Electric Industries SAS. All rights reserved.

Author

> Larry Turner, Schneider Electric, Analytics & AI, 2020-09-23.

Definition

class `diamondback.interfaces.IVersion.` `IVersion`

  Bases: `diamondback.interfaces.IEqual.IEqual`

  Version interface.

  Initialize.

  property `version`

    str.

    Type

      version

  `__eq__`(other: Any) → bool

    Equal.

    Arguments :

    > other : typing.Any.

    Returns :

    > equal : bool.

## Module contents